@@ -46,7 +46,7 @@ use Data::Dumper;
 
 #  Version information
 #
-$VERSION='2.020';
+$VERSION='2.022';
 
 
 #  Debug load
@@ -245,7 +245,27 @@ sub parse_fh {
             debug("add CR at EOF");
             $html.=$/ unless $html=~/(?:\r?\n|\r)$/;
         }
-
+        
+        
+        #  Ugly hack to fix @ type attribute names in Alpine and Vue. Need to be done in the Parser properly at
+        #  some stage
+        #
+        if (my $attr_convert=$WEBDYNE_ALPINE_VUE_ATTRIBUTE_HACK_ENABLE) {
+            if ($html =~ s{
+                (<\s*[\w:-]+             # match the start of an HTML tag
+                (?:\s+[^>]*?)?)          # non-greedy match of attributes
+                \s@([\w\.-]+)            # match attribute like @click or @keydown.enter
+                (\s*=\s*["'][^"']*["'])  # match = "value" or = 'value'
+            }{
+                "$1 ${attr_convert}:$2$3"
+            }egx) {
+                debug("match on AlpineJS attribute syntax hack, line now: $line");
+            }
+            else {
+                debug('no match on AlpineJS attribute syntax hack')
+            }
+        }
+        
 
         #  Done, return HTML
         #
@@ -290,6 +310,20 @@ sub tag_parse {
     #  Get the tag, tag attr
     #
     my ($tag, $attr_hr)=@_;
+    
+    
+    #  Get rid of attribute multi-line value if the start with subst cars
+    #
+    foreach my $attr (keys %{$attr_hr}) {
+        my $attr_value=$attr_hr->{$attr};
+        if ($attr_value=~/([\$@%!+*^])\{(\1?)/) {
+            #  Get rid of cr/lf
+            if ($attr_value=~s/\s*[\r\n]+\s*/ /g) {
+                $attr_hr->{$attr}=$attr_value;
+            }
+        }
+    }
+    #map { $attr_hr->{$_}=($attr_hr->{$_}=~s/\s*[\r\n]+\s*/ /gr) } keys %{$attr_hr};
 
 
     #  Debug
@@ -450,13 +484,33 @@ sub tag_parse {
 
 
     }
-
-
-    #  Insert line number if possible
+    
+    
+    #  Do we have a HTML::Element object ?
     #
-    debug("insert line_no: %s, line_no_start: %s into object ref $html_or", @{$self}{qw(_line_no _line_no_start)});
-    debug('tag %s', $html_or->tag()) if (ref($html_or));
-    ref($html_or) && (@{$html_or}{'_line_no', '_line_no_tag_end'}=(@{$self}{qw(_line_no_start _line_no)}));
+    if ((my $ref=ref($html_or)) eq 'HTML::Element') {
+        
+        #  Yes
+        #
+        debug("parse returned $ref object, tag: %s, inserting line no", $html_or->tag());
+        @{$html_or}{'_line_no', '_line_no_tag_end'}=@{$self}{qw(_line_no_start _line_no)};
+        
+        
+    }
+    elsif ($ref && ($ref ne 'WebDyne::HTML::TreeBuilder')) {
+    
+        #  That's weird ..
+        #
+        return err("parse returned $ref object, expected 'WebDyne::HTML::Element'");
+        
+    }
+    else {    
+        
+        #  Text
+        #
+        debug('parse returned text (scalar) object');
+        
+    }
 
 
     #  Returm object ref
@@ -482,6 +536,7 @@ sub block {
 sub script {
 
     my ($self, $method, $tag, $attr_hr, @param)=@_;
+    no warnings 'qw';
     debug("$self script, attr: %s", Dumper($attr_hr));
     my $script_or=$self->$method($tag, $attr_hr, @param);
     if ($attr_hr->{'type'} eq 'application/perl') {
@@ -936,25 +991,50 @@ sub text {
 
             #  Meeds subst. Get rid of cr's at start and end of text after a <perl> tag, stuffs up formatting in <pre> sections
             #
-            debug("found subst tag line_no_start: %s, line_no: %s, text '$text'", @{$self}{qw(_line_no_start _line_no)});
-            my @cr=($text=~/\n/g);
-            if (my $html_or=$self->{'_pos'}) {
-                debug("parent %s", $html_or->tag());
-                if (($html_or->tag() eq 'perl') && !$html_or->attr('inline')) {
-                    debug('hit !');
+            debug("found subst tag line_no_start: %s, line_no: %s, text '$text', script_stack: %s, %s", @{$self}{qw(_line_no_start _line_no _script_stack)}, Dumper($self->{'_script_stack'}));
 
-                    #  Why did I comment this out ?
-                    #
-                    #$text=~s/^\n//;
-                    #$text=~s/\n$//;
-                }
+            #my @cr=($text=~/\n/g);
+            #if (my $html_or=$self->{'_pos'}) {
+            #    debug("parent %s", $html_or->tag());
+            #    if (($html_or->tag() eq 'perl') && !$html_or->attr('inline')) {
+            #        debug('hit !');
+            #
+            #        #  Why did I comment this out ?
+            #        #
+            #        #$text=~s/^\n//;
+            #        #$text=~s/\n$//;
+            #    }
+            #}
+            
+            #  If in <script> block we probably don't want to be running subst over strings we find because ${varname} is valid Javascript 
+            #  syntax and we shouldn't reallt ever need to subs in a script block (user can pass params to script). Nevertheless we'll give
+            #  them a subst option if they want
+            #
+            my $html_or=$self->{'_pos'};
+            my %attr=$html_or->all_external_attr();
+            
+            
+            #  Gets a bit ugly for <script> tags. If <script> is Javascript *dont* run subst over it unless the user insists.
+            #
+            #  First - are we inside a script tag. Easiest way is to see if in script_stack
+            #
+            if (@{$self->{'_script_stack'}} && (!$attr{'type'} || $WEBDYNE_SCRIPT_TYPE_EXECUTABLE_HR->{$attr{'type'}}) && !$attr{'subst'}) {
+            #if (@{$self->{'_script_stack'}} && !$attr{'subst'}) {
+                debug("script_stack present, bypass susbt: parent %s, attr: %s", $html_or->tag(), Dumper(\%attr));
+                $self->tag_parse('SUPER::text', $text)
+            
+            }
+            elsif ($attr{'nosubst'}) {
+                debug('nosubst attr found in attr: %s', Dumper(\%attr));
+                $self->tag_parse('SUPER::text', $text)
+            }
+            else {
+                my $html_subst_or=HTML::Element->new('subst');
+                debug("insert line_no: %s, line_no_tag_end: %s into object ref $html_subst_or for text $text", @{$self}{qw(_line_no_start _line_no)});
+                @{$html_subst_or}{'_line_no', '_line_no_tag_end'}=@{$self}{qw(_line_no _line_no)};
+                $html_subst_or->push_content($text);
+                $self->tag_parse('SUPER::text', $html_subst_or)
             }
-
-            my $html_or=HTML::Element->new('subst');
-            debug("insert line_no: %s, line_no_tag_end: %s into object ref $html_or for text $text, cr %s", @{$self}{qw(_line_no_start _line_no)}, scalar @cr);
-            @{$html_or}{'_line_no', '_line_no_tag_end'}=@{$self}{qw(_line_no _line_no)};
-            $html_or->push_content($text);
-            $self->tag_parse('SUPER::text', $html_or)
         }
         else {
 
@@ -997,6 +1077,7 @@ sub comment {
 sub start_html {
 
     my ($self, $method, $tag, $attr_hr)=@_;
+    debug("self: $self, method: $method, tag: $tag, attr_hr: %s", Dumper($attr_hr));
     push @{$self->{'_html_wedge_ar'}}, (my $html=$self->{'_html_tiny_or'}->$tag($attr_hr));
     return $self;
 
